--[[
    ... links and notes should be here ...
]]

local _, addonTable = ...
local _c = addonTable.config

if not _c.showSpellID then
    return -- ignore the code below
end

local hexColor = _c.spellIDTextColor:GenerateHexColor()

local function addLine(tooltip, id)
    if not id then return end

    tooltip:AddLine('|c' .. hexColor .. _c.spellIDText .. '|r ' .. id, 1, 1, 1)
    tooltip:Show() -- update borders correctly
end

local function onTooltipSetSpell(self)
    local id = select(2, self:GetSpell())

    -- Fix duplicate line issue in PlayerTalentFrame (isRetail)
    for i = self:NumLines(), 3, -1 do
        local lineText = _G[self:GetName() .. 'TextLeft' .. i]:GetText()

        -- If the "Spell ID" line is found
        if string.match(lineText, _c.spellIDText) then
            return -- stop the loop and exit the function
        end
    end
    addLine(self, id)
end

local function setUnitAura(self, unit, index, filter)
    local id = select(10, UnitAura(unit, index, filter))

    addLine(self, id)
end

GameTooltip:HookScript('OnTooltipSetSpell', onTooltipSetSpell) -- SpellBookFrame, PlayerTalentFrame, ...
hooksecurefunc(GameTooltip, 'SetUnitAura', setUnitAura) -- BuffFrame
hooksecurefunc(GameTooltip, 'SetUnitBuff', setUnitAura) -- UnitFrame
hooksecurefunc(GameTooltip, 'SetUnitDebuff', setUnitAura) -- UnitFrame